==> hedra-0.7.2-py3-none-any.whl: hedra/core/graphs/transitions/local_transitions.py <==
from hedra.core.graphs.stages.types.stage_types import StageTypes
from .common.transtition_metadata import TransitionMetadata


local_transitions = {

        # State: Idle
        (StageTypes.IDLE, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.IDLE, StageTypes.WAIT):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.IDLE, StageTypes.SETUP):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.VALIDATE):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.IDLE, StageTypes.OPTIMIZE):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.EXECUTE):   TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.TEARDOWN):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.ANALYZE):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.CHECKPOINT):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.SUBMIT):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.COMPLETE):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.ERROR):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),

        # State: Wait
        (StageTypes.WAIT, StageTypes.WAIT):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.WAIT, StageTypes.IDLE):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.WAIT, StageTypes.SETUP):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.WAIT, StageTypes.VALIDATE):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.WAIT, StageTypes.OPTIMIZE):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.WAIT, StageTypes.EXECUTE):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.WAIT, StageTypes.TEARDOWN):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.WAIT, StageTypes.ANALYZE):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.WAIT, StageTypes.CHECKPOINT):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.WAIT, StageTypes.SUBMIT):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.WAIT, StageTypes.COMPLETE):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.WAIT, StageTypes.ERROR):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),

        # State: Setup
        (StageTypes.SETUP, StageTypes.SETUP):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SETUP, StageTypes.IDLE):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SETUP, StageTypes.WAIT):  TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SETUP, StageTypes.VALIDATE):  TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SETUP, StageTypes.OPTIMIZE):  TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SETUP, StageTypes.EXECUTE):  TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SETUP, StageTypes.TEARDOWN):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SETUP, StageTypes.ANALYZE):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SETUP, StageTypes.CHECKPOINT):  TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SETUP, StageTypes.SUBMIT):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SETUP, StageTypes.COMPLETE):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SETUP, StageTypes.ERROR):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Validate
        (StageTypes.VALIDATE, StageTypes.VALIDATE):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.VALIDATE, StageTypes.IDLE):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.VALIDATE, StageTypes.WAIT):  TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.VALIDATE, StageTypes.SETUP):  TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.VALIDATE, StageTypes.OPTIMIZE):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.VALIDATE, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.VALIDATE, StageTypes.TEARDOWN): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.VALIDATE, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.VALIDATE, StageTypes.CHECKPOINT): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.VALIDATE, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.VALIDATE, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.VALIDATE, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Optimize
        (StageTypes.OPTIMIZE, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.WAIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.OPTIMIZE, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.VALIDATE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.OPTIMIZE, StageTypes.TEARDOWN): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.CHECKPOINT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.OPTIMIZE, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Execute
        (StageTypes.EXECUTE, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.EXECUTE, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.EXECUTE, StageTypes.WAIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.EXECUTE, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.EXECUTE, StageTypes.VALIDATE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.EXECUTE, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.EXECUTE, StageTypes.TEARDOWN): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.EXECUTE, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.EXECUTE, StageTypes.CHECKPOINT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.EXECUTE, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.EXECUTE, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.EXECUTE, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Teardown
        (StageTypes.TEARDOWN, StageTypes.TEARDOWN): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.TEARDOWN, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.TEARDOWN, StageTypes.WAIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.TEARDOWN, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.TEARDOWN, StageTypes.VALIDATE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.TEARDOWN, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.TEARDOWN, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.TEARDOWN, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.TEARDOWN, StageTypes.CHECKPOINT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.TEARDOWN, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.TEARDOWN, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.TEARDOWN, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Analyze
        (StageTypes.ANALYZE, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.WAIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.ANALYZE, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.VALIDATE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.TEARDOWN): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.CHECKPOINT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.ANALYZE, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.ANALYZE, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Checkpoint
        (StageTypes.CHECKPOINT, StageTypes.CHECKPOINT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.CHECKPOINT, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.CHECKPOINT, StageTypes.WAIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.CHECKPOINT, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.CHECKPOINT, StageTypes.VALIDATE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.CHECKPOINT, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.CHECKPOINT, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.CHECKPOINT, StageTypes.TEARDOWN): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.CHECKPOINT, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.CHECKPOINT, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.CHECKPOINT, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.CHECKPOINT, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),


        # State: Submit
        (StageTypes.SUBMIT, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SUBMIT, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SUBMIT, StageTypes.WAIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SUBMIT, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SUBMIT, StageTypes.VALIDATE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SUBMIT, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SUBMIT, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SUBMIT, StageTypes.TEARDOWN): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SUBMIT, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SUBMIT, StageTypes.CHECKPOINT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SUBMIT, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SUBMIT, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Complete
        (StageTypes.COMPLETE, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.WAIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.VALIDATE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.TEARDOWN): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.CHECKPOINT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Error
        (StageTypes.ERROR, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.WAIT): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.VALIDATE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.TEARDOWN): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.CHECKPOINT): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=False)
    }

==> hedra-0.7.3-py3-none-any.whl: hedra/core/graphs/transitions/local_transitions.py <==
from hedra.core.graphs.stages.types.stage_types import StageTypes
from .common.transtition_metadata import TransitionMetadata


local_transitions = {

        # State: Idle
        (StageTypes.IDLE, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.IDLE, StageTypes.SETUP):  TransitionMetadata(allow_multiple_edges=True, is_valid=True),
        (StageTypes.IDLE, StageTypes.OPTIMIZE):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.EXECUTE):   TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.ANALYZE):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.SUBMIT):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.COMPLETE):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),
        (StageTypes.IDLE, StageTypes.ERROR):  TransitionMetadata(allow_multiple_edges=True, is_valid=False),

        # State: Setup
        (StageTypes.SETUP, StageTypes.SETUP):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SETUP, StageTypes.IDLE):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SETUP, StageTypes.OPTIMIZE):  TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SETUP, StageTypes.EXECUTE):  TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SETUP, StageTypes.ANALYZE):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SETUP, StageTypes.SUBMIT):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SETUP, StageTypes.COMPLETE):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SETUP, StageTypes.ERROR):  TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Optimize
        (StageTypes.OPTIMIZE, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.OPTIMIZE, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.OPTIMIZE, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Execute
        (StageTypes.EXECUTE, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.EXECUTE, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.EXECUTE, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.EXECUTE, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.EXECUTE, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.EXECUTE, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.EXECUTE, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.EXECUTE, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Analyze
        (StageTypes.ANALYZE, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.ANALYZE, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ANALYZE, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Submit
        (StageTypes.SUBMIT, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SUBMIT, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SUBMIT, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SUBMIT, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SUBMIT, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SUBMIT, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.SUBMIT, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.SUBMIT, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Complete
        (StageTypes.COMPLETE, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=True),
        (StageTypes.COMPLETE, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),

        # State: Error
        (StageTypes.ERROR, StageTypes.ERROR): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.IDLE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.SETUP): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.OPTIMIZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.EXECUTE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.ANALYZE): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.SUBMIT): TransitionMetadata(allow_multiple_edges=False, is_valid=False),
        (StageTypes.ERROR, StageTypes.COMPLETE): TransitionMetadata(allow_multiple_edges=False, is_valid=False)
    }
